==> tecfy_core_package-1.0.14.tar.gz: lib/models/user.model.dart <==
part of tecfy_core_client_package;

class User {
  late String id;
  String? username;
  late String fullName;
  late String? email;
  String? mobile;
  String? identityNo;
  String? code;
  String? display;
  String? photoUrl;
  int? recordNumber;
  bool isSuperuser = false;
  bool canSellWithoutInventory = false;
  bool canAccessPOS = false;
  bool canSellCredit = false;
  num maxDiscountPercentageSalesInvoice = 0;
  List<String> stores = [];
  List<String> paymentMethods = [];
  User(
      {required this.id,
      required this.recordNumber,
      this.username,
      this.mobile,
      this.email,
      required this.fullName,
      this.photoUrl,
      this.display,
      this.code,
      this.identityNo,
      this.canSellCredit = false,
      this.maxDiscountPercentageSalesInvoice = 0,
      this.isSuperuser = false,
      this.canSellWithoutInventory = false,
      this.canAccessPOS = true});

  User.fromJson(Map<String, dynamic>? map) {
    if (map == null) return;
    id = map['id'].toString();
    recordNumber = map['recordNumber'];
    username = map['username'] ?? '';
    fullName = map['fullName'] ?? '';
    email = map['email'] ?? '';
    mobile = map['mobile'] ?? '';
    identityNo = map['identityNo'] ?? '';
    code = map['code'] ?? '';
    display = map['display'] ?? '';
    isSuperuser = map['isSuperuser'] ?? false;
    canSellWithoutInventory = map['canSellWithoutInventory'] ?? false;
    canAccessPOS = map['canAccessPOS'] ?? true;
    canSellCredit = map['canSellCredit'] ?? true;
    maxDiscountPercentageSalesInvoice =
        map['maxDiscountPercentageSalesInvoice'];
    if (map['stores'] != null)
      stores = map['stores'].map<String>((e) => e.toString()).toList();
    if (map['paymentMethods'] != null)
      paymentMethods =
          map['paymentMethods'].map<String>((e) => e.toString()).toList();
  }

  toJson() {
    return {
      'id': id,
      'recordNumber': recordNumber,
      'username': username,
      'fullName': fullName,
      'code': code,
      'mobile': mobile,
      'identityNo': identityNo,
      'email': email,
      'display': display,
      'isSuperuser': isSuperuser,
      'canSellWithoutInventory': canSellWithoutInventory,
      'canAccessPOS': canAccessPOS,
      'canSellCredit': canSellCredit,
      'maxDiscountPercentageSalesInvoice': maxDiscountPercentageSalesInvoice,
      'stores': stores,
      'paymentMethods': paymentMethods
    };
  }
}

==> tecfy_core_package-1.0.23.tar.gz: lib/models/user.model.dart <==
part of tecfy_core_client_package;

class User {
  late String id;
  String? username;
  late String fullName;
  late String? email;
  String? mobile;
  String? identityNo;
  String? code;
  String? display;
  String? photoUrl;
  int? recordNumber;
  bool isSuperuser = false;
  bool canSellWithoutInventory = false;
  bool canAccessPOS = false;
  bool canSellCredit = false;
  bool canViewPosRegisterValues = false;
  num maxDiscountPercentageSalesInvoice = 0;
  List<String> stores = [];
  List<String> paymentMethods = [];
  User(
      {required this.id,
      required this.recordNumber,
      this.username,
      this.mobile,
      this.email,
      required this.fullName,
      this.photoUrl,
      this.display,
      this.code,
      this.identityNo,
      this.canSellCredit = false,
      this.canViewPosRegisterValues = false,
      this.maxDiscountPercentageSalesInvoice = 0,
      this.isSuperuser = false,
      this.canSellWithoutInventory = false,
      this.canAccessPOS = true});

  User.fromJson(Map<String, dynamic>? map) {
    if (map == null) return;
    id = map['id'].toString();
    recordNumber = map['recordNumber'];
    username = map['username'] ?? '';
    fullName = map['fullName'] ?? '';
    email = map['email'] ?? '';
    mobile = map['mobile'] ?? '';
    identityNo = map['identityNo'] ?? '';
    code = map['code'] ?? '';
    display = map['display'] ?? '';
    isSuperuser = BaseModel.getBoolEx(map['isSuperuser']);
    canSellWithoutInventory =
        BaseModel.getBoolEx(map['canSellWithoutInventory']);
    canAccessPOS = BaseModel.getBoolEx(map['canAccessPOS']);
    canSellCredit = BaseModel.getBoolEx(map['canSellCredit']);
    canViewPosRegisterValues =
        BaseModel.getBoolEx(map['canViewPosRegisterValues']);
    maxDiscountPercentageSalesInvoice =
        map['maxDiscountPercentageSalesInvoice'];
    if (map['stores'] != null)
      stores = map['stores'].map<String>((e) => e.toString()).toList();
    if (map['paymentMethods'] != null)
      paymentMethods =
          map['paymentMethods'].map<String>((e) => e.toString()).toList();
  }

  toJson() {
    return {
      'id': id,
      'recordNumber': recordNumber,
      'username': username,
      'fullName': fullName,
      'code': code,
      'mobile': mobile,
      'identityNo': identityNo,
      'email': email,
      'display': display,
      'isSuperuser': isSuperuser,
      'canSellWithoutInventory': canSellWithoutInventory,
      'canAccessPOS': canAccessPOS,
      'canSellCredit': canSellCredit,
      'canViewPosRegisterValues': canViewPosRegisterValues,
      'maxDiscountPercentageSalesInvoice': maxDiscountPercentageSalesInvoice,
      'stores': stores,
      'paymentMethods': paymentMethods
    };
  }
}
